EXPORTS
	?DeleteFileL@RPIMTestServer@@QAEXABVTDesC16@@@Z @ 1 NONAME ; void RPIMTestServer::DeleteFileL(class TDesC16 const &)
	?SetHomeTime@RPIMTestServer@@QAEHABVTTime@@@Z @ 2 NONAME ; int RPIMTestServer::SetHomeTime(class TTime const &)
	?CheckForFile@RPIMTestServer@@QAEHABVTDesC16@@@Z @ 3 NONAME ; int RPIMTestServer::CheckForFile(class TDesC16 const &)
	?KillProcessL@RPIMTestServer@@QAEXABVTDesC16@@@Z @ 4 NONAME ; void RPIMTestServer::KillProcessL(class TDesC16 const &)
	?ChangeLocaleNameL@RPIMTestServer@@QAEXABVTDesC16@@@Z @ 5 NONAME ; void RPIMTestServer::ChangeLocaleNameL(class TDesC16 const &)
	?Connect@RPIMTestServer@@QAEHXZ @ 6 NONAME ; int RPIMTestServer::Connect(void)
	?CopyFileL@RPIMTestServer@@QAEXABVTDesC16@@0@Z @ 7 NONAME ; void RPIMTestServer::CopyFileL(class TDesC16 const &, class TDesC16 const &)
	?CreateEmptyFileL@RPIMTestServer@@QAEXABVTDesC16@@@Z @ 8 NONAME ; void RPIMTestServer::CreateEmptyFileL(class TDesC16 const &)
	?SetTimeZoneL@RPIMTestServer@@QAEXABVTDesC8@@@Z @ 9 NONAME ; void RPIMTestServer::SetTimeZoneL(class TDesC8 const &)
	?GetTimeZoneL@RPIMTestServer@@QAEXAAVTDes8@@@Z @ 10 NONAME ; void RPIMTestServer::GetTimeZoneL(class TDes8 &)
	?CreateLogFileLC@CTestRegister@@QAEXAAVRFile@@ABVTDesC16@@@Z @ 11 NONAME ; void CTestRegister::CreateLogFileLC(class RFile &, class TDesC16 const &)
	?CreateTempFileLC@CTestRegister@@QAEXAAVRFile@@ABVTDesC16@@@Z @ 12 NONAME ; void CTestRegister::CreateTempFileLC(class RFile &, class TDesC16 const &)
	?GetLogPath@CTestRegister@@QAEXAAVTDes16@@@Z @ 13 NONAME ; void CTestRegister::GetLogPath(class TDes16 &)
	?GetTempPath@CTestRegister@@QAEXAAVTDes16@@@Z @ 14 NONAME ; void CTestRegister::GetTempPath(class TDes16 &)
	?NewLC@CTestRegister@@SAPAV1@XZ @ 15 NONAME ; class CTestRegister * CTestRegister::NewLC(void)
	?OpenLogFileLC@CTestRegister@@QAEXAAVRFile@@ABVTDesC16@@@Z @ 16 NONAME ; void CTestRegister::OpenLogFileLC(class RFile &, class TDesC16 const &)
	?OpenTempFileLC@CTestRegister@@QAEXAAVRFile@@ABVTDesC16@@@Z @ 17 NONAME ; void CTestRegister::OpenTempFileLC(class RFile &, class TDesC16 const &)
	?RegisterL@CTestRegister@@QAEXABVTDesC16@@W4TTempFileType@@@Z @ 18 NONAME ; void CTestRegister::RegisterL(class TDesC16 const &, enum TTempFileType)
	?DeleteDirL@RPIMTestServer@@QAEXABVTDesC16@@@Z @ 19 NONAME ; void RPIMTestServer::DeleteDirL(class TDesC16 const &)
	?GetFileSizeL@RPIMTestServer@@QAEHABVTDesC16@@@Z @ 20 NONAME ; int RPIMTestServer::GetFileSizeL(class TDesC16 const &)
	?NewL@CTestRegister@@SAPAV1@XZ @ 21 NONAME ; class CTestRegister * CTestRegister::NewL(void)
	?FileServerNotifyChange@RPIMTestServer@@QAEXW4TNotifyType@@AAVTRequestStatus@@ABVTDesC16@@@Z @ 22 NONAME ; void RPIMTestServer::FileServerNotifyChange(enum TNotifyType, class TRequestStatus &, class TDesC16 const &)
	?FileServerNotifyChangeCancel@RPIMTestServer@@QAEXXZ @ 23 NONAME ; void RPIMTestServer::FileServerNotifyChangeCancel(void)
	?CloseTzSession@RPIMTestServer@@QAEXXZ @ 24  NONAME ; void RPIMTestServer::CloseTzSession(void)
	?ChangeFSAttributesL@RPIMTestServer@@QAEXABVTDesC16@@II@Z @ 25 NONAME ; void RPIMTestServer::ChangeFSAttributesL(class TDesC16 const &, unsigned int, unsigned int)
	??1CAlarmEventWatcher@@UAE@XZ @ 26 NONAME ; CAlarmEventWatcher::~CAlarmEventWatcher(void)
	?StartWaitingForEventL@CAlarmEventWatcher@@QAEXW4TAlarmChangeEvent@@VTTimeIntervalMicroSeconds@@W4TPriority@CActive@@@Z @ 27 NONAME ; void CAlarmEventWatcher::StartWaitingForEventL(enum TAlarmChangeEvent, class TTimeIntervalMicroSeconds, enum CActive::TPriority)
	?StartTimer@CNotificationTimer@@QAEXVTTimeIntervalMicroSeconds@@W4TPriority@CActive@@@Z @ 28 NONAME ; void CNotificationTimer::StartTimer(class TTimeIntervalMicroSeconds, enum CActive::TPriority)
	?NewL@CNotificationTimer@@SAPAV1@XZ @ 29 NONAME ; class CNotificationTimer * CNotificationTimer::NewL(void)
	?GetProperty@CPropertyWatcher@@QAEAAVRProperty@@XZ @ 30 NONAME ; class RProperty & CPropertyWatcher::GetProperty(void)
	??1CPropertyWatcher@@UAE@XZ @ 31 NONAME ; CPropertyWatcher::~CPropertyWatcher(void)
	?StartWatchingL@CPropertyWatcher@@QAEXVTTimeIntervalMicroSeconds@@W4TPriority@CActive@@@Z @ 32 NONAME ; void CPropertyWatcher::StartWatchingL(class TTimeIntervalMicroSeconds, enum CActive::TPriority)
	??1CNotificationTimer@@UAE@XZ @ 33 NONAME ; CNotificationTimer::~CNotificationTimer(void)
	?NewL@CPropertyWatcher@@SAPAV1@VTUid@@IW4TOwnerType@@@Z @ 34 NONAME ; class CPropertyWatcher * CPropertyWatcher::NewL(class TUid, unsigned int, enum TOwnerType)
	?StopTimer@CNotificationTimer@@QAEXXZ @ 35 NONAME ; void CNotificationTimer::StopTimer(void)
	?NewL@CAlarmEventWatcher@@SAPAV1@AAVRASCliSession@@@Z @ 36 NONAME ; class CAlarmEventWatcher * CAlarmEventWatcher::NewL(class RASCliSession &)
	?HasTimedOut@CNotificationTimer@@QBEHXZ @ 37 NONAME ; int CNotificationTimer::HasTimedOut(void) const
	?DeleteFilesInDirL@RPIMTestServer@@QAEXABVTDesC16@@@Z @ 38  NONAME ; void RPIMTestServer::DeleteFilesInDirL(class TDesC16 const &)
	?CopyDirAndFilesL@RPIMTestServer@@QAEXABVTDesC16@@0@Z @ 39  NONAME ; void RPIMTestServer::CopyDirAndFilesL(class TDesC16 const &, class TDesC16 const &)


	
